aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/runtime/ILifetimeManager.h
diff options
context:
space:
mode:
Diffstat (limited to 'arm_compute/runtime/ILifetimeManager.h')
-rw-r--r--arm_compute/runtime/ILifetimeManager.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/arm_compute/runtime/ILifetimeManager.h b/arm_compute/runtime/ILifetimeManager.h
index 36743ac404..f2e9b497c9 100644
--- a/arm_compute/runtime/ILifetimeManager.h
+++ b/arm_compute/runtime/ILifetimeManager.h
@@ -32,8 +32,10 @@
namespace arm_compute
{
-class IMemoryGroup;
+// Forward declarations
class IAllocator;
+class IMemory;
+class IMemoryGroup;
/** Interface for managing the lifetime of objects */
class ILifetimeManager
@@ -53,11 +55,11 @@ public:
virtual void start_lifetime(void *obj) = 0;
/** Ends lifetime of an object
*
* @param[in] obj Object
* @param[in] handle Memory handle of the object
* @param[in] size Size of the given object at given time
*/
- virtual void end_lifetime(void *obj, void **handle, size_t size) = 0;
+ virtual void end_lifetime(void *obj, IMemory &obj_memory, size_t size) = 0;
/** Checks if the lifetime of the registered object is complete
*
* @return True if all object lifetimes are finalized else false.
@@ -53,11 +55,11 @@ public:
/** Ends lifetime of an object
*
- * @param[in] obj Object
- * @param[in] handle Memory handle of the object
- * @param[in] size Size of the given object at given time
+ * @param[in] obj Object
+ * @param[in] obj_memory Object memory
+ * @param[in] size Size of the given object at given time
*/